@@ -1,6 +1,9 @@
 #include "monitor.ih"
 
 Monitor::Monitor()
+:
+    d_arg(Arg::instance()),
+    d_sorterPath(Util::makeAbsPath(d_arg[0]))
 {
     processControlOptions();            // handle process control options
     maybeBackground();                  // maybe run Stealth in the background
@@ -14,6 +17,7 @@ Monitor::Monitor()
     signal(SIGTERM, Monitor::handleProcessSignals);
     signal(SIGUSR1, Monitor::handleProcessSignals);
     signal(SIGUSR2, Monitor::handleProcessSignals);
+    signal(SIGPIPE, Monitor::handleProcessSignals);
 }
 
 
