@@ -8,6 +8,20 @@ void Monitor::processMode()
     {
         switch (s_mode)
         {
+            default:
+                d_scanner->run(&s_quit);
+
+                if (s_mode == TERMINATE || s_mode == SUPPRESS)
+                    continue;
+            return;
+
+            case RELOAD:
+                *d_reporter << 
+                    "STEALTH reloads its configuration files after " << 
+                    d_scanner->nScans() << " scans at " << now << endl;
+                reload();
+            return;              // next cycle: rerun a scan.
+    
             case TERMINATE:
                 *d_reporter << 
                     "STEALTH was terminated after " << d_scanner->nScans() << 
@@ -26,12 +40,6 @@ void Monitor::processMode()
             case SUPPRESSED:
             return;
 
-            default:
-                d_scanner->run(&s_quit);
-
-                if (s_mode == TERMINATE || s_mode == SUPPRESS)
-                    continue;
-            return;
         }
     }
 }
