@@ -2,5 +2,5 @@
 
 void Monitor::sleep()
 {
-    s_selector.setAlarm(INT_MAX);
+    s_selector.setAlarm(numeric_limits<int>::max());
 }
