@@ -6,20 +6,16 @@
 
 void Reporter::standby()
 {
-    if (!Util::lockRunFile(Util::NONBLOCKING))  // wait for the lock on an 
+    if (!Lock::lockRunFile(Lock::NONBLOCKING))  // wait for the lock on an 
         return;                                 // existing run file. 
                                                 // No run file: no lock
 
     d_out.open(d_name.c_str(), ios::out | ios::ate | ios::in);
-    if (!d_out.is_open())
+    if (!d_out)
     {
         d_out.clear();
-        d_out.open(d_name.c_str(), ios::out | ios::in | ios::trunc);    
-                                                        // open if construction
-    }                                                   // fails: new file
-
-    if (!d_out.is_open())
-        throw Errno("Can't open ") << insertable << d_name << throwable;
+        Errno::open(d_out, d_name, ios::out | ios::in | ios::trunc);    
+    }
 
     reinit();
 }
