@@ -12,16 +12,15 @@ void Scanner::removeLOG()
         // remove 'LOG =' and proceed.
         if (pos != string::npos && matched[pos] == '=')
         {
-            Util::debug() << "removed `LOG =', kept `" << 
-                            matched.substr(pos + 1) << "'" << endl;
+            imsg << "removed `LOG =', kept `" << 
+                            matched.substr(pos + 1) << '\'' << endl;
             s_firstWord.match(matched.substr(pos + 1));
         }
         else
-            Util::debug() << "LOG is (partial) logname in `" << 
-                                                    matched << "'" << endl;
+            imsg << "LOG is (partial) logname in `" << matched << '\'' << 
+                                                                        endl;
     }
     else
-        Util::debug() << "No `LOG =' in CHECK command `" << matched << "'" <<
-                                                                        endl;
+        imsg << "No `LOG =' in CHECK command `" << matched << "'" << endl;
 }
 
