@@ -1,18 +1,18 @@
 #include "scanner.ih"
 
-void Scanner::setSkip(string const &fname)
+void Scanner::setSkip()
 {
     ifstream in;
-    Errno::open(in, fname);
+    Errno::open(in, d_skipFilePath);
 
     for_each(
-        istream_iterator<Line>(in), istream_iterator<Line>(), 
+        istream_iterator<StringLine>(in), istream_iterator<StringLine>(), 
         [&](std::string const &line)
         {
             add(line, d_skipFiles);
         }
     );
-    
+
     d_skip = &Scanner::skip;
 }
 
