@@ -7,10 +7,10 @@ void Scanner::write(string const &fname)
     ifstream source(fname.c_str());
 
     if (!source)
-        d_reporter.exit() << "Can't open `" << fname << "' to read" << endl;
+        d_reporter.error() << "Can't open `" << fname << "' to read\n";
 
-    Util::debug() << "Scanner::write(): about to read local `" << fname << 
-                                                                "'" << endl;
+    imsg << "Scanner::write(): about to read local `" << fname << '\'' << 
+                                                                        endl;
     while (true)
     {
         size_t const SIZEOF_BUF = 1000;
@@ -22,7 +22,7 @@ void Scanner::write(string const &fname)
             break;
 
         if (!d_sshFork.write(buffer, nRead))
-            d_reporter.exit() << "PUT failed." << endl;
+            d_reporter.error() << "PUT failed.\n";
     }
 
     d_sshFork.flush();
